@@ -6,7 +6,7 @@ with open('requirements.txt') as f:
 
 setup(
     name='dsFramework',
-    py_modules=['api_cli'],
+    py_modules=['api_cli', 'dsFramework'],
     packages=[
         'cli',
         'lib',
@@ -20,7 +20,7 @@ setup(
         [console_scripts]
         ds-framework-cli=api_cli:cli
     ''',
-    version='0.1.1',
+    version='0.1.4',
     description='My first Python library',
     # url='http://pypi.python.org/pypi/PackageName/',
     author='oribrau@gmail.com',
